Terality is the serverless & lightning fast Python data processing engine.

Terality’s engine enable data scientists and engineers to transform and manipulate data at light speed, with the exact same syntax as Pandas, with zero sever management.

You will need a Terality account to use this package. Check out our documentation to get started https://docs.terality.com/.